package com.ti.mobpo.ui.screens

import androidx.compose.foundation.Image
import com.ti.mobpo.ui.PokeSearchViewModel
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.aspectRatio
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.items
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.ti.mobpo.R
import com.ti.mobpo.ui.SearchBar
import androidx.lifecycle.viewmodel.compose.viewModel
import com.ti.mobpo.model.PokemonDetails
import coil.compose.AsyncImage
import coil.request.ImageRequest
import com.ti.mobpo.ui.theme.MobileSecurityTheme

@Composable
fun PokeSearchScreen(pokeSearchViewModel: PokeSearchViewModel) {
    PokeSearch(pokeSearchViewModel)
}

@Composable
fun PokeSearch(pokeSearchViewModel: PokeSearchViewModel) {
    val searchResults by pokeSearchViewModel.pokemonDetails.collectAsState()

    Column(
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = Modifier
            .fillMaxSize()
            .padding(20.dp)
    ) {
        SearchBar(stringResource(R.string.input_field_label)) { value ->
            pokeSearchViewModel.search(value)
        }

        Spacer(modifier = Modifier.height(16.dp))

        searchResults?.let { results ->
            if (results.isNotEmpty()) {
                LazyVerticalGrid(
                    columns = GridCells.Adaptive(150.dp),
                    verticalArrangement = Arrangement.spacedBy(10.dp)
                ) {
                    items(items = results, key = { pokemon -> pokemon.id }) { pokemon ->
                        PokemonCard(pokemon)
                    }
                }
            } else {
                Text("No results found")
            }
        }
    }
}


@Composable
fun PokemonCard(pokemon: PokemonDetails) {
    Card(
        shape = MaterialTheme.shapes.medium,
        elevation = CardDefaults.cardElevation(defaultElevation = 8.dp),
        modifier = Modifier
            .padding(4.dp)
            .fillMaxWidth()
            .aspectRatio(1f)
    ) {
        Column(
            modifier = Modifier.fillMaxSize(),
            verticalArrangement = Arrangement.Bottom
        ) {
            AsyncImage(
                model = ImageRequest.Builder(context = LocalContext.current).data(pokemon.sprites.other.officialArtwork.frontDefault)
                    .crossfade(true).build(),
                contentDescription = pokemon.name,
                contentScale = ContentScale.Crop,
                modifier = Modifier
                    .fillMaxWidth()
                    .weight(1f)
            )
            Text(
                text = pokemon.name.replace("-", " "),
                style = MaterialTheme.typography.bodySmall,
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(horizontal = 8.dp, vertical = 4.dp) // Adjust padding as needed
                    .wrapContentSize(Alignment.Center)
            )
        }
    }
}


@Preview(showBackground = true)
@Composable
fun PokeSearchApp(){
    val pokeSearchViewModel: PokeSearchViewModel = viewModel()
    PokeSearchScreen(pokeSearchViewModel)
}

@Preview(showBackground = true)
@Composable
fun PhotosGridScreenPreview() {
    MobileSecurityTheme {
    }
}